@@ -16,7 +16,7 @@ import torch.nn.functional
 from hsh.library.hash import Hasher
 from tqdm import tqdm
 from .u2net import detect, u2net
-from ..backgroundremover import utilities
+from . import utilities
 
 DEVICE = torch.device('cuda:0' if torch.cuda.is_available() else 'cpu')
 
@@ -63,7 +63,7 @@ class Net(torch.nn.Module):
             )
             if (
                 not os.path.exists(path)
-                or hasher.md5(path) != "347c3d51b01528e5c6c071e3cff1cb55"
+                or hasher.md5(path) != "09fb4e49b7f785c9f855baf94916840a"
             ):
                 utilities.download_file_from_google_drive(
                     model, path,
@@ -77,7 +77,7 @@ class Net(torch.nn.Module):
             )
             if (
                 not os.path.exists(path)
-                or hasher.md5(path) != "09fb4e49b7f785c9f855baf94916840a"
+                or hasher.md5(path) != "347c3d51b01528e5c6c071e3cff1cb55"
             ):
                 utilities.download_file_from_google_drive(
                     model, path,
