@@ -11,7 +11,7 @@ from torchvision import transforms
 from tqdm import tqdm
 
 from . import data_loader, u2net
-from ...backgroundremover import utilities
+from .. import utilities
 
 def load_model(model_name: str = "u2net"):
     hasher = Hasher()
@@ -53,7 +53,7 @@ def load_model(model_name: str = "u2net"):
         )
         if (
             not os.path.exists(path)
-            or hasher.md5(path) != "347c3d51b01528e5c6c071e3cff1cb55"
+            or hasher.md5(path) != "09fb4e49b7f785c9f855baf94916840a"
         ):
             utilities.download_file_from_google_drive(
                 model, path,
@@ -67,7 +67,7 @@ def load_model(model_name: str = "u2net"):
         )
         if (
             not os.path.exists(path)
-            or hasher.md5(path) != "09fb4e49b7f785c9f855baf94916840a"
+            or hasher.md5(path) != "347c3d51b01528e5c6c071e3cff1cb55"
         ):
             utilities.download_file_from_google_drive(
                 model, path,
